@@ -16,7 +16,7 @@ from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:  # pragma: no cover
     from hoppr_cyclonedx_models.cyclonedx_1_4 import (
-        CyclonedxSoftwareBillOfMaterialsStandard as Bom,
+        CyclonedxSoftwareBillOfMaterialsStandard as Bom,  # type: ignore
     )
 
     from hoppr.configs.manifest import Manifest
