@@ -10,8 +10,8 @@ from hoppr import __version__
 from hoppr.base_plugins.collector import CollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.context import Context
-from hoppr.result import Result
 from hoppr.hoppr_types.cred_object import CredObject
+from hoppr.result import Result
 
 
 class CollectHelmPlugin(CollectorPlugin):
@@ -78,7 +78,7 @@ class CollectHelmPlugin(CollectorPlugin):
             return Result.retry(msg)
 
         self.get_logger().info(
-            "Complete helm chart artifact copy for {purl.to_string()}"
+            f"Complete helm chart artifact copy for {purl.to_string()}"
         )
 
         return Result.success()
