@@ -4,7 +4,6 @@ Run Hoppr processing, using multiple processors
 from __future__ import annotations
 
 import logging
-from multiprocessing import cpu_count
 import os
 import platform
 import shutil
@@ -14,12 +13,13 @@ import urllib
 from concurrent.futures import Future, ProcessPoolExecutor
 from datetime import datetime
 from itertools import zip_longest
+from multiprocessing import cpu_count
 from pathlib import Path
 from typing import Dict, List, Optional, Tuple
 
+from hoppr_cyclonedx_models.cyclonedx_1_4 import Component  # type: ignore
 from packageurl import PackageURL  # type: ignore
 from typer import echo
-from hoppr_cyclonedx_models.cyclonedx_1_4 import Component
 
 from hoppr.base_plugins.hoppr import HopprPlugin
 from hoppr.configs.manifest import Manifest
@@ -27,13 +27,13 @@ from hoppr.configs.transfer import Transfer
 from hoppr.context import Context
 from hoppr.exceptions import HopprPluginError
 from hoppr.flatten_sboms import flatten_sboms
+from hoppr.hoppr_types.transfer_file_content import Plugin as PluginRef
 from hoppr.net import download_file
 from hoppr.result import Result
-from hoppr.hoppr_types.transfer_file_content import Plugin as PluginRef
 from hoppr.utils import plugin_instance
 
 if "nux" in platform.system():
-    import pwd
+    import pwd  # pylint: disable=import-error
 
 
 def _run_plugin(
@@ -272,7 +272,7 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
         os.makedirs(target_dir, exist_ok=True)
 
         if "nux" in platform.system():
-            user = pwd.getpwuid(os.getuid())[0]
+            user = pwd.getpwuid(os.getuid())[0]  # pylint: disable=no-member
         else:
             user = os.getlogin()
 
